@@ -9,9 +9,11 @@ class DES(BaseAttractors):
     def __init__(self, attractor, init_coord, params):
         super(DES, self).__init__(attractor, params)
         self.coord = init_coord
-        self.X = []
-        self.Y = []
-        self.Z = []
+        self.X = 0
+        self.Y = 0
+        self.Z = 0
+        self.ts = None
+        self.N = None
 
     def __lt__(self, other):
         if not isinstance(other, DES):
@@ -24,27 +26,30 @@ class DES(BaseAttractors):
         return self.X == other.X and self.Y == other.Y and self.Z == other.Z
 
     def __len__(self):
-        return len(self.X)
+        return self.N
 
     def _unwrap(self, a, b, N):
+        self.N = N
         h = (b - a) / N
-        timescale = np.arange(a, b, h)
         attractor_func = getattr(DES, self.attractor)
-        return h, timescale, attractor_func
+        return h, attractor_func
 
     def euler(self, a, b, N):
-        h, ts, afunc = self._unwrap(a, b, N)
+        h, afunc = self._unwrap(a, b, N)
 
-        for _ in ts:
-            self.X.append(self.coord[0])
-            self.Y.append(self.coord[1])
-            self.Z.append(self.coord[2])
+        for ts in range(N):
+
+            self.X = self.coord[0]
+            self.Y = self.coord[1]
+            self.Z = self.coord[2]
 
             k1 = h * afunc(self, self.coord)
             self.coord += k1
+            self.ts = ts
+            yield self
 
     def rk2(self, a, b, N, method):
-        h, ts, afunc = self._unwrap(a, b, N)
+        h, afunc = self._unwrap(a, b, N)
 
         def heun():
             rt = self.coord
@@ -76,19 +81,25 @@ class DES(BaseAttractors):
 
             self.coord += (k1 + 2 * k2) / 3
 
-        for _ in ts:
-            self.X.append(self.coord[0])
-            self.Y.append(self.coord[1])
-            self.Z.append(self.coord[2])
+        for ts in range(N):
+
+            self.X = self.coord[0]
+            self.Y = self.coord[1]
+            self.Z = self.coord[2]
+
             eval(method)()
 
-    def rk3(self, a, b, N):
-        h, ts, afunc = self._unwrap(a, b, N)
+            self.ts = ts
+            yield self
 
-        for _ in ts:
-            self.X.append(self.coord[0])
-            self.Y.append(self.coord[1])
-            self.Z.append(self.coord[2])
+    def rk3(self, a, b, N):
+        h, afunc = self._unwrap(a, b, N)
+
+        for ts in range(N):
+
+            self.X = self.coord[0]
+            self.Y = self.coord[1]
+            self.Z = self.coord[2]
 
             rt = self.coord
             k1 = h * afunc(self, self.coord)
@@ -103,13 +114,17 @@ class DES(BaseAttractors):
 
             self.coord += (k1 + 4 * k2 + k3) / 6
 
-    def rk4(self, a, b, N):
-        h, ts, afunc = self._unwrap(a, b, N)
+            self.ts = ts
+            yield self
 
-        for _ in ts:
-            self.X.append(self.coord[0])
-            self.Y.append(self.coord[1])
-            self.Z.append(self.coord[2])
+    def rk4(self, a, b, N):
+        h, afunc = self._unwrap(a, b, N)
+
+        for ts in range(N):
+
+            self.X = self.coord[0]
+            self.Y = self.coord[1]
+            self.Z = self.coord[2]
 
             rt = self.coord
             k1 = h * afunc(self, self.coord)
@@ -128,13 +143,16 @@ class DES(BaseAttractors):
 
             self.coord += (k1 + 2 * k2 + 2 * k3 + k4) / 6
 
-    def rk5(self, a, b, N):
-        h, ts, afunc = self._unwrap(a, b, N)
+            self.ts = ts
+            yield self
 
-        for _ in ts:
-            self.X.append(self.coord[0])
-            self.Y.append(self.coord[1])
-            self.Z.append(self.coord[2])
+    def rk5(self, a, b, N):
+        h, afunc = self._unwrap(a, b, N)
+
+        for ts in range(N):
+            self.X = self.coord[0]
+            self.Y = self.coord[1]
+            self.Z = self.coord[2]
 
             rt = self.coord
             k1 = h * afunc(self, self.coord)
@@ -167,3 +185,6 @@ class DES(BaseAttractors):
             self.coord = rt
 
             self.coord += (7 * k1 + 32 * k3 + 12 * k4 + 32 * k5 + 7 * k6) / 90
+
+            self.ts = ts
+            yield self
